@@ -3,13 +3,15 @@
 """Igloo: a command line pastebin client.
 
 Usage:
-  igloo [-t TITLE] [-s SYNTAX] [-p PRIVACY] [-e EXPIRATION] [FILE] ...
+  igloo [-o] [-t TITLE] [-s SYNTAX] [-p PRIVACY] [-e EXPIRATION] [FILE] ...
   igloo (-l | --list)
   igloo (-r | --reset)
   igloo (-h | --help)
   igloo --version
 
-Creates a pastebin from files or standard input and returns the pastebin's URL.
+Creates a pastebin from files or standard input and returns the pastebin's URL
+or opens the corresponding page in your browser.
+
 You must have a pastebin.com account to use igloo. The first time you use
 igloo you will be prompted for your api developer key (which can be found at
 http://pastebin.com/api) along with your user name and password. Igloo then
@@ -29,6 +31,7 @@ Arguments:
 Options:
   -h --help                               Show this screen.
   --version                               Show version.
+  -o --open                               Open browser after creating pastebin.
   -t TITLE --title=TITLE                  Title of snippet.
   -s SYNTAX --syntax=SYNTAX               Highlighting format.
   -p PRIVACY --privacy=PRIVACY            Privacy level [default: unlisted].
@@ -39,7 +42,7 @@ Options:
 
 """
 
-__version__ = '0.0.8'
+__version__ = '0.0.9'
 
 
 from getpass import getpass
@@ -47,6 +50,7 @@ from json import dump, load
 from os import remove
 from os.path import expanduser, join
 from sys import stdin
+from webbrowser import open as open_webbrowser
 
 try:
   from docopt import docopt
@@ -159,8 +163,7 @@ class Client(object):
       data['api_paste_expire_date'] = expiration
     if syntax:
       data['api_paste_format'] = syntax
-    url = self._get_response(data)
-    print 'Pastebin successfully created!\n%s' % (url, )
+    return self._get_response(data)
 
   def view_list_of_pastes(self):
     """View all pastes by logged in user."""
@@ -194,13 +197,17 @@ def main():
       content = '\n\n'.join(contents)
     else:
       content = stdin.read()
-    client.create_paste(
+    url = client.create_paste(
       content,
       title=arguments['--title'],
       syntax=arguments['--syntax'],
       privacy=arguments['--privacy'],
       expiration=arguments['--expiration']
     )
+    if arguments['--open']:
+      open_webbrowser(url)
+    else:
+      print 'Pastebin successfully created!\n%s' % (url, )
 
 if __name__ == '__main__':
   main()
